/**
 * This non-chainable plugin defines the header and footer look for all Hubtel apps. 
 * Assumes the project has JQuery(>=2.0)
 * @author: Michael K. Ocansey (ocansey@smsgh.com)
 * @version: 1.0
 * @return: string
 * @copyright: July 2016, SMSGH Ltd.
 */

// this prevents FOUC (flash of unstyled content)
document.getElementsByTagName("html")[0].style.display = "none";

( function($) {

    
    var BaseUrl = "http://apptemplate.local/pages/";
    var DefaultMenuItems = [];

    $.fn.HubtelGlobalBar = function( options ) {
        
        // set default options
        var Settings = 
        $.extend({
            BarType : "header",
            AppMenus : DefaultMenuItems,
            AppLogo: BaseUrl+"assets/img/logo-hubtel.png",
            LoggedInUsername: "DemoUser",
            LoggedInUserPic: BaseUrl+"assets/img/profiles/avatar_small2x.jpg",
            ShowAppMenuBar: true,
            AccountBalance: "0.00 Credits",
            CallBack: ""
        }, options);

        // determine if user needs header or footer
        ( Settings.BarType == "header" ) ? HubtelHeader(this, Settings) : HubtelFooter(this);
                

        function HubtelHeader(Obj, Settings) {
            /*
             * using jquery load to pull in the html page.. this allows the designers to do their own thing to the file 
             * alternatives to this would be to use 
             * - $.ajax [ with dataType: "jsonp"]
             * - XMLHttpRequest
             * - HTML5 FileReader API
             * - local proxies
             * NOTE: set Access-Control-Allow-Origin "*" on resource server should you run into CORS issues
             * !!! plugin-header.html must exist and be reachable from BaseUrl+'plugin-header.html'
             * */

            WriteScriptsAndStyles();
            $('body').addClass('fixed-header');
            Obj.html('<div class="hubtel-jqplugin-header"></div>');

            $('.hubtel-jqplugin-header').load(BaseUrl+"plugin-header.html", function(ResponseText) {
                ParsedHtml = ResponseText.replace(/{{logo}}/g, '<img src="'+Settings.AppLogo+
                            '" alt="logo" data-src="'+Settings.AppLogo+'"'+
                            ' data-src-retina="'+Settings.AppLogo+'" class="jqp-app-logo">');
                ParsedHtml = ParsedHtml.replace(/{{credits}}/g, '<div class="jqp-account-balance-0711">'+Settings.AccountBalance+'</div>');
                ParsedHtml = ParsedHtml.replace(/{{username}}/g, Settings.LoggedInUsername);
                ParsedHtml = ParsedHtml.replace(/{{avatar}}/g, '<img src="'+Settings.LoggedInUserPic+
                            '" alt="avatar" class="avatar" data-src="'+Settings.LoggedInUserPic+
                            '" data-src-retina="'+Settings.LoggedInUserPic+'" width="32" height="32">');
                ParsedHtml = ParsedHtml.replace(/{{menuitems}}/g, ParseAppMenus(Settings.AppMenus));
                $(this).html(ParsedHtml);
                if( !Settings.ShowAppMenuBar ) $('.jq-app-header').remove();
                
                $(window).load(function() { 
                    $("html").removeAttr("style");
                    if( Settings.CallBack != '' ) eval(Settings.CallBack); 
                });
            });
        }

        function WriteScriptsAndStyles() {

            // array of dependent css and js files
            ScriptStyles = [
                { FileType: "css",  FilePath: "plugins/bootstrap/css/bootstrap.min" },
                { FileType: "css",  FilePath: "pages/css/pages" },
                { FileType: "css",  FilePath: "assets/css/hubtel" },
                { FileType: "css",  FilePath: "assets/css/app" },
                { FileType: "js",   FilePath: "assets/plugins/modernizr.custom" },
                { FileType: "js",   FilePath: "plugins/bootstrap/js/bootstrap.min" },
                { FileType: "js",   FilePath: "https://use.fontawesome.com/3adec3b39e" },
                { FileType: "js",   FilePath: "pages/js/pages" }
            ];

            TotalScripts = ScriptStyles.length;
            for ( x=0; x< TotalScripts; x++ ) {
                FileType = ScriptStyles[x].FileType;
                FilePath = (ScriptStyles[x].FilePath.indexOf('http') != -1) ? ScriptStyles[x].FilePath : BaseUrl + ScriptStyles[x].FilePath;
                
                ( FileType == "css" ) ? 
                    $("head").append('<link href="'+FilePath+'.'+FileType+'" rel="stylesheet" type="text/css">') : 
                    $("body").append('<script src="'+FilePath+'.'+FileType+'" type="text/javascript"></script>');
            }
            // set the global favicon to hubtel icon 
            $("head").append('<link href="'+BaseUrl+'assets/img/favicon.png" rel="shortcut icon" type="image/png">');
            
        }

        function HubtelFooter(Obj) {
            /**
             * !!! plugin-footer.html must exist and be reachable from BaseUrl+'plugin-footer.html'
             */
            Obj.html('<div class="hubtel-jqplugin-footer"></div>');
            $('.hubtel-jqplugin-footer').load(BaseUrl+"plugin-footer.html", function(ResponseText){
                d = new Date(); 
                ThisYear = d.getFullYear();
                ParsedHtml = ResponseText.replace(/{{this_year}}/g, ThisYear);
                $(this).html(ParsedHtml);
            });
        }

        function ParseAppMenus(MenuItems) {
            /**
             * traverse app menu parameter and build topbar navigation
             */
            if ($.isArray(MenuItems)) {
                var TotalMenuItems = MenuItems.length;
                var ReturnVal = '';
                for (var x=0; x < TotalMenuItems; x++ ) {
                    var LinkName = MenuItems[x].LinkName;
                    var LinkNameForCss = 'jqp-' + LinkName.replace(/\s/g, '-').toLowerCase();
                    var Url = MenuItems[x].Url;

                    if($.isArray(Url)) {
                        ReturnVal += '<li class="dropdown"><a href="javascript:;">'+LinkName+
                                     '</a><ul class="dropdown-menu">'+ParseAppMenus(Url)+'</ul></li>';
                    } else {
                        ReturnVal += '<li><a href="'+SanitizeUrl(Url)+'" class="'+LinkNameForCss+'">'+LinkName+'</a>';
                    }
                }   return ReturnVal+ '';
            }
            return 'AppMenu has to be an array';
        }

        function SanitizeUrl(Url) {
            WhiteListDomains = [
                "smsgh.com",
                "hubtel.com"
            ]
            var matches = "lala".match( /\d/ );
            return Url;
        }

    };

} (jQuery));